#!/usr/bin/env python


"""
Gurunudi Language codes for different languages
"""

ABKHAZIAN ="abk"
AFAR ="aar"
AFRIKAANS ="afr"
AHOM ="aho"
ALBANIAN ="sqi"
ARABIC ="ara"
ARMENIAN ="hye"
AZERBAIJANI ="aze"
BALINESE ="ban"
BAMUM ="bax"
BASQUE ="eus"
BASSA ="bsq"
BATAK ="btk"
BELARUSIAN ="bel"
BENGALI ="ben"
BOSNIAN ="bos"
BUGINESE ="bug"
BUHID ="bku"
BULGARIAN ="bul"
BURMESE ="mya"
MYANMAR ="mya"
CATALAN ="cat"
CEBUANO ="ceb"
CENTRAL_KHMER ="khm"
CAMBODIAN ="khm"
CHAKMA ="ccp"
CHINESE ="zho"
CORSICAN ="cos"
CROATIAN ="hrv"
CZECH ="ces"
DANISH ="dan"
DUTCH ="nld"
ENGLISH ="eng"
ESPERANTO ="epo"
ESTONIAN ="est"
FILIPINO ="fil"
FINNISH ="fin"
FRENCH ="fra"
FULA ="ful"
GALICIAN ="glg"
GEORGIAN ="kat"
GERMAN ="deu"
GOAN_KONKANI ="gom"
GREEK ="ell"
GUJARATI ="guj"
HAITIAN ="hat"
HANUNOO ="hnn"
HAUSA ="hau"
HAWAIIAN ="haw"
HEBREW ="heb"
HINDI ="hin"
HMONG ="hmn"
HUNGARIAN ="hun"
ICELANDIC ="isl"
IGBO ="ibo"
INDONESIAN ="ind"
IRISH ="gle"
ITALIAN ="ita"
JAPANESE ="jpn"
JAVANESE ="jav"
KANNADA ="kan"
KAZAKH ="kaz"
KONKANI ="kok"
KOREAN ="kor"
KURDISH ="kur"
LAO ="lao"
LATIN ="lat"
LATVIAN ="lav"
LEPTCHA ="lep"
LIMBU ="lif"
LISU ="lis"
LITHUANIAN ="lit"
MACEDONIAN ="mkd"
MAITHILI ="mai"
MALAGASY ="mlg"
MALAY ="msa"
MALAYALAM ="mal"
MALTESE ="mlt"
MANDARIN_CHINESE ="cmn"
MAORI ="mri"
MARATHI ="mar"
MENDE ="men"
MONGOLIAN ="mon"
MRU ="mro"
NEPALI ="nep"
NORTH_TAIRORA ="tbg"
NORWEGIAN ="nor"
NORWEGIAN_BOKMAL ="nob"
NORWEGIAN_NYNORSK ="nno"
NYANJA ="nya"
ODIA ="ori"
ORIYA ="ori"
PERSIAN ="fas"
POLISH ="pol"
PORTUGUESE ="por"
PRAKRIT ="pra"
PUNJABI ="pan"
PUSHTO ="pus"
ROMANIAN ="ron"
RUSSIAN ="rus"
SANSKRIT ="san"
SANTALI ="sat"
SARAIKI ="skr"
MULTANI ="skr"
SAURASHTRA ="saz"
SERBIAN ="srp"
SINHALA ="sin"
SLOVAK ="slk"
SLOVENIAN ="slv"
SOMALI ="som"
SORA ="srb"
SOUTH_TAIRORA ="omw"
SOUTHERN_SOTHO ="sot"
SPANISH ="spa"
SUNDANESE ="sun"
SWAHILI ="swa"
SWEDISH ="swe"
TAGALOG ="tgl"
TAI_NUA ="tdd"
TAJIK ="tgk"
TAMIL ="tam"
TANGUT ="txg"
TELUGU ="tel"
THAI ="tha"
TULU ="tcy"
TURKISH ="tur"
UKRAINIAN ="ukr"
URDU ="urd"
UZBEK ="uzb"
VAI ="vai"
VIETNAMESE ="vie"
WELSH ="cym"
WESTERN_FRISIAN ="fry"
YIDDISH ="yid"
YORUBA ="yor"
ZULU ="zul"


names={'abk': 'Abkhazian', 'aar': 'Afar', 'afr': 'Afrikaans', 'aho': 'Ahom', 'sqi': 'Albanian', 'ara': 'Arabic', 'hye': 'Armenian', 'aze': 'Azerbaijani', 'ban': 'Balinese', 'bax': 'Bamum', 'eus': 'Basque', 'bsq': 'Bassa', 'btk': 'Batak', 'bel': 'Belarusian', 'ben': 'Bengali', 'bos': 'Bosnian', 'bug': 'Buginese', 'bku': 'Buhid', 'bul': 'Bulgarian', 'mya': 'Burmese', 'cat': 'Catalan', 'ceb': 'Cebuano', 'khm': 'Central Khmer', 'ccp': 'Chakma', 'zho': 'Chinese', 'cos': 'Corsican', 'hrv': 'Croatian', 'ces': 'Czech', 'dan': 'Danish', 'nld': 'Dutch', 'eng': 'English', 'epo': 'Esperanto', 'est': 'Estonian', 'fil': 'Filipino', 'fin': 'Finnish', 'fra': 'French', 'ful': 'Fula', 'glg': 'Galician', 'kat': 'Georgian', 'deu': 'German', 'gom': 'Goan Konkani', 'ell': 'Greek', 'guj': 'Gujarati', 'hat': 'Haitian', 'hnn': 'Hanunoo', 'hau': 'Hausa', 'haw': 'Hawaiian', 'heb': 'Hebrew', 'hin': 'Hindi', 'hmn': 'Hmong', 'hun': 'Hungarian', 'isl': 'Icelandic', 'ibo': 'Igbo', 'ind': 'Indonesian', 'gle': 'Irish', 'ita': 'Italian', 'jpn': 'Japanese', 'jav': 'Javanese', 'kan': 'Kannada', 'kaz': 'Kazakh', 'kok': 'Konkani', 'kor': 'Korean', 'kur': 'Kurdish', 'lao': 'Lao', 'lat': 'Latin', 'lav': 'Latvian', 'lep': 'Leptcha', 'lif': 'Limbu', 'lis': 'Lisu', 'lit': 'Lithuanian', 'mkd': 'Macedonian', 'mai': 'Maithili', 'mlg': 'Malagasy', 'msa': 'Malay', 'mal': 'Malayalam', 'mlt': 'Maltese', 'cmn': 'Mandarin Chinese', 'mri': 'Maori', 'mar': 'Marathi', 'men': 'Mende', 'mon': 'Mongolian', 'mro': 'Mru', 'nep': 'Nepali', 'tbg': 'North Tairora', 'nor': 'Norwegian', 'nob': 'Norwegian Bokmal', 'nno': 'Norwegian Nynorsk', 'nya': 'Nyanja', 'ori': 'Oriya', 'fas': 'Persian', 'pol': 'Polish', 'por': 'Portuguese', 'pra': 'Prakrit', 'pan': 'Punjabi', 'pus': 'Pushto', 'ron': 'Romanian', 'rus': 'Russian', 'san': 'Sanskrit', 'sat': 'Santali', 'skr': 'Saraiki', 'saz': 'Saurashtra', 'srp': 'Serbian', 'sin': 'Sinhala', 'slk': 'Slovak', 'slv': 'Slovenian', 'som': 'Somali', 'srb': 'Sora', 'omw': 'South Tairora', 'sot': 'Southern Sotho', 'spa': 'Spanish', 'sun': 'Sundanese', 'swa': 'Swahili', 'swe': 'Swedish', 'tgl': 'Tagalog', 'tdd': 'Tai Nua', 'tgk': 'Tajik', 'tam': 'Tamil', 'txg': 'Tangut', 'tel': 'Telugu', 'tha': 'Thai', 'tcy': 'Tulu', 'tur': 'Turkish', 'ukr': 'Ukrainian', 'urd': 'Urdu', 'uzb': 'Uzbek', 'vai': 'Vai', 'vie': 'Vietnamese', 'cym': 'Welsh', 'fry': 'Western Frisian', 'yid': 'Yiddish', 'yor': 'Yoruba', 'zul': 'Zulu'}
